@@ -21,6 +21,12 @@ pub struct Opt {
 
 #[derive(Debug, StructOpt)]
 pub enum Command {
+    /// Burn token
+    #[structopt(name = "burn")]
+    Burn {
+        #[structopt(subcommand)]
+        burn_subcommands: BurnSubcommands,
+    },
     /// Decode on-chain data into JSON format
     #[structopt(name = "decode")]
     Decode {
@@ -64,6 +70,20 @@ pub enum Command {
     },
 }
 
+#[derive(Debug, StructOpt)]
+pub enum BurnSubcommands {
+    #[structopt(name = "one")]
+    One {
+        /// Path to the authority & funder keypair file
+        #[structopt(short, long)]
+        keypair: String,
+
+        /// Token mint account
+        #[structopt(short, long)]
+        account: String,
+    },
+}
+
 #[derive(Debug, StructOpt)]
 pub enum DecodeSubcommands {
     /// Decode a mint account's metadata
@@ -231,6 +251,10 @@ pub enum SignSubcommands {
         #[structopt(short, long)]
         candy_machine_id: Option<String>,
 
+        /// Candy machine v2 id
+        #[structopt(long = "v2")]
+        v2: bool,
+
         /// Path to JSON file with list of mint accounts to sign
         #[structopt(short, long)]
         mint_accounts_file: Option<String>,
